<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.2/1886137
 */

namespace Application\Model;

use P4\Connection\ConnectionInterface;

/**
 * Interface for all Swarm DAOs to implement
 * @package Application\Model
 */
interface IModelDAO
{
    // Aliases for DAOs
    const USER_DAO     = 'userDAO';
    const GROUP_DAO    = 'groupDAO';
    const PROJECT_DAO  = 'projectDAO';
    const WORKFLOW_DAO = 'workflowDAO';
    const KEY_DAO      = 'keyDAO';
    const CHANGE_DAO   = 'changeDAO';

    const FETCHALL       = 'fetchAll';
    const FETCH          = 'fetch';
    const FETCH_NO_CACHE = 'noCache';
    // Only fetch the model summary data
    const FETCH_SUMMARY = 'summary';
    // Option to specify sort fields when fetching all
    const SORT = 'sort';

    /**
     * Tests if a record exists.
     * @param string            $id         the id of the record, for example a user id.
     * @param ConnectionInterface|null $connection the P4 connection
     * @return mixed
     */
    public function exists($id, ConnectionInterface $connection = null);

    /**
     * Examines the array of ids and returns those that exist
     * @param array                     $ids            ids to examine
     * @param ConnectionInterface|null  $connection     the connection
     * @return array an array of ids that exist, or an empty array if none are valid
     */
    public function existIds(array $ids, ConnectionInterface $connection = null) : array;

    /**
     * Fetches all records.
     * @param array             $options    fetch all options.
     * @param ConnectionInterface|null $connection the P4 connection
     * @return mixed
     */
    public function fetchAll(array $options = [], ConnectionInterface $connection = null);

    /**
     * Fetch a record by its id.
     * @param string            $id         the id of the record, for example a user id.
     * @param ConnectionInterface|null $connection the P4 connection
     * @return mixed
     * @deprecated Use fetchById
     */
    public function fetch($id, ConnectionInterface $connection = null);

    /**
     * Fetch a record by its id.
     *
     * @param string            $id         the id of the record, for example a user id.
     * @param ConnectionInterface|null $connection the P4 connection
     * @return mixed
     */
    public function fetchById($id, ConnectionInterface $connection = null);

    /**
     * Save the model.
     * @param mixed     $model  the Perforce model class to save
     * @return mixed
     */
    public function save($model);

    /**
     * Delete the model.
     * @param mixed     $model  the Perforce model class to save
     * @return mixed
     */
    public function delete($model);
}
