<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.2/1886137
 */

namespace Users\View\Helper;

use Users\Model\User as UserModel;
use Application\View\Helper\AbstractHelper;
use Application\Config\ConfigManager;

class UserLink extends AbstractHelper
{
    /**
     * Outputs the user ID and linkifies it if the user exists
     *
     * @param   string  $user       the user id to output and, if able, link to
     * @param   bool    $strong     optional, if false (default) not strong, if true user id wrapped in strong tag
     * @param   string  $baseUrl    optional, if specified, given string will be pre-pended to links
     * @return  string  the user id as a link if the user exists
     */
    public function __invoke($user, $strong = false, $baseUrl = null)
    {
        $view     = $this->getView();
        $services = $this->services;
        $p4Admin  = $services->get('p4_admin');
        $label    = $view->escapeHtml($user);

        if ($strong) {
            $label = '<strong>' . $label . '</strong>';
        }

        if (!UserModel::exists($user, $p4Admin)) {
            return $label;
        }
        $fullname        =  UserModel::fetchById($user, $p4Admin)->get('FullName');
        $displayFullName = ConfigManager::getValue($services->get('config'), ConfigManager::DISPLAY_FULLNAME);
        $label           = $displayFullName ? $fullname : $label;
        $title           = $displayFullName ? $fullname . " (" .$user .")" : $fullname;


        return '<a alt="'.$title.'" title="'.$title.'" href="' . $baseUrl
            . $view->url('user', ['user' => $user]) . '">'. $label . '</a>';
    }
}
